# Pytest covid. 


> When you do testing to that extent, you're going to find more people, you're going to find more cases. So I said to my people, slow the testing down — please

The more failures you'll get the more tests it will skil.

```
# pytest.ini
[pytest]
[covid]
enabled = True
fake_news = False
```

Or if you like Fox News set `fake_news = True` and test failures will be reported as success.
